<?php
/**
 * Copyright (C) 2021  Jaap Jansma (jaap.jansma@civicoop.org)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

use CRM_Phoneinputmask_ExtensionUtil as E;

class CRM_Phoneinputmask_Page_PhoneInputMask extends CRM_Core_Page_Basic {

  /**
   * The action links that we need to display for the browse screen.
   *
   * @var array
   */
  public static $_links = array();

  /**
   * Name of the BAO to perform various DB manipulations.
   *
   * @return string
   */
  protected function getBAOName() {
    return 'CRM_Phoneinputmask_BAO_PhoneInputMask';
  }

  /**
   * Get action Links.
   *
   * @return array
   *   (reference) of action links
   */
  public function &links() {
    if (!(self::$_links)) {
      self::$_links = [
        CRM_Core_Action::UPDATE => [
          'name' => E::ts('Edit'),
          'url' => 'civicrm/admin/phoneinputmask',
          'qs' => 'action=update&id=%%id%%&reset=1',
          'title' => E::ts('Edit Phone Input Mask'),
        ],
        CRM_Core_Action::DISABLE => [
          'name' => E::ts('Disable'),
          'ref' => 'crm-enable-disable',
          'title' => E::ts('Disable Phone Input Mask'),
        ],
        CRM_Core_Action::ENABLE => [
          'name' => E::ts('Enable'),
          'ref' => 'crm-enable-disable',
          'title' => E::ts('Enable Phone Input Mask'),
        ],
        CRM_Core_Action::DELETE => [
          'name' => E::ts('Delete'),
          'url' => 'civicrm/admin/phoneinputmask',
          'qs' => 'action=delete&id=%%id%%',
          'title' => E::ts('Delete Phone Input Mask'),
        ],
      ];
    }
    return self::$_links;
  }

  /**
   * Name of the edit form class.
   *
   * @return string
   */
  protected function editForm() {
    return 'CRM_Phoneinputmask_Form_PhoneInputMask';
  }

  /**
   * Name of the form.
   *
   * @return string
   */
  protected function editName() {
    return 'Phone Input Mask';
  }

  /**
   * UserContext to pop back to.
   *
   * @param int $mode
   *   Mode that we are in.
   *
   * @return string
   */
  protected function userContext($mode = NULL) {
    return 'civicrm/admin/phoneinputmask';
  }

  /**
   * Run the basic page (run essentially starts execution for that page).
   */
  public function run() {
    CRM_Utils_System::setTitle(E::ts('Phone Input Mask'));
    parent::run();
  }

}
