<?php
/**
 * Copyright (C) 2021  Jaap Jansma (jaap.jansma@civicoop.org)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

use CRM_Phoneinputmask_ExtensionUtil as E;

class CRM_Phoneinputmask_Utils_CommonForm {

  /**
   * Implements hook_civicrm_validateForm().
   *
   * @param string $formName
   * @param array $fields
   * @param array $files
   * @param CRM_Core_Form $form
   * @param array $errors
   */
  public static function hookValidateForm($formName, &$fields, &$files, &$form, &$errors) {
    $statusMsgAdded = false;
    $validFormNames = [
      'CRM_Contact_Form_Inline_Phone',
      'CRM_Contact_Form_Contact',
      'CRM_Campaign_Form_Petition_Signature',
      'CRM_Contribute_Form_Contribution_Main',
      'CRM_Event_Form_Registration_Register',
      'CRM_Profile_Form_Edit',
    ];
    if (in_array($formName, $validFormNames)) {
      foreach ($fields['phone'] as $phoneIndex => $phone) {
        if (empty($phone['phone'])) {
          continue;
        }
        if (!CRM_Phoneinputmask_Utils_CommonForm::validatePhone($phone['phone'])) {
          $examples = '<strong>' . E::ts('The phone number you entered doesn\'t meet the predefined format requirements. Please use these examples for orientation:') . '</strong>';
          $examples .= '<ul>';
          foreach (CRM_Phoneinputmask_Utils_CommonForm::getExamples() as $example) {
            $examples .= '<li>'.$example.'</li>';
          }
          $examples .= '</ul>';
          if (!$statusMsgAdded) {
            CRM_Core_Session::setStatus($examples, E::ts('Example Phone Numbers'), 'info');
            $statusMsgAdded = true;
          }
          $errors['phone[' . $phoneIndex . '][phone]'] = E::ts('Invalid phone number');
        }
      }
    }
  }

  public static function validatePhone($phone) {
    $factory = phoneinputmask_get_factory();
    $types = $factory->getTypes();
    $inValidCount = 0;
    $validCount = 0;
    $masks = \Civi\Api4\PhoneInputMask::get(FALSE)->addWhere('is_active', '=', '1')->execute();
    foreach($masks as $mask) {
      /** @var \Civi\PhoneInputMask\TypeInterface $typeClass */
      $typeClass = $types[$mask['type']];
      $typeClass->initialize($mask['name'], $mask['title'], $mask['configuration']);
      if (!$typeClass->validatePhone($phone)) {
        $inValidCount ++;
      } else {
        $validCount ++;
      }
    }
    if ($validCount === 0 && $inValidCount > 0) {
      return false;
    }
    return true;
  }

  /**
   * @return array|String[]
   * @throws \API_Exception
   * @throws \Civi\API\Exception\UnauthorizedException
   */
  public static function getExamples() {
    $factory = phoneinputmask_get_factory();
    $types = $factory->getTypes();
    $examples = array();
    $masks = \Civi\Api4\PhoneInputMask::get(FALSE)->addWhere('is_active', '=', '1')->execute();
    foreach($masks as $mask) {
      /** @var \Civi\PhoneInputMask\TypeInterface $typeClass */
      $typeClass = $types[$mask['type']];
      $typeClass->initialize($mask['name'], $mask['title'], $mask['configuration']);
      $examples = array_merge($examples, $typeClass->getExamples());
    }
    return $examples;
  }

}
