<?php
/**
 * Copyright (C) 2021  Jaap Jansma (jaap.jansma@civicoop.org)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

namespace Civi\PhoneInputMask;

use Civi\ConfigItems\Entity\Factory;
use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\Definition;

class CompilerPass implements CompilerPassInterface {

  public function process(ContainerBuilder $container) {
    $phoneInputMaskFactory = $this->createDefinitionClass('Civi\PhoneInputMask\Factory');
    $phoneInputMaskFactory->addMethodCall('addType', ['mask', new Definition('\Civi\PhoneInputMask\Type\Mask')]);
    $phoneInputMaskFactory->addMethodCall('addType', ['e123', new Definition('\Civi\PhoneInputMask\Type\E123')]);
    $phoneInputMaskFactory->addMethodCall('addType', ['din5008', new Definition('\Civi\PhoneInputMask\Type\DIN5008')]);
    $phoneInputMaskFactory->addMethodCall('addType', ['duden', new Definition('\Civi\PhoneInputMask\Type\Duden')]);
    $container->setDefinition('phone_input_mask_factory', $phoneInputMaskFactory);

    if ($container->hasDefinition('civiconfig_entity_factory')) {
      $container->getDefinition('civiconfig_entity_factory')
        ->addMethodCall('addEntityDefinition', [new Definition('\Civi\ConfigItems\Entity\SimpleEntity\Definition', ['PhoneInputMask']), Factory::EARLY_PRIORITY]);
    }
  }

  /**
   * Returns a definition class.
   * We have to set is private to false on the definition class
   * with newer versions of civicrm (especially with civicrm and drupal 9)
   * with older versions of civicrm the setPrivate method is not available so we cannot set it.
   *
   * @param null $class
   * @param array $arguments
   * @return \Symfony\Component\DependencyInjection\Definition
   */
  private function createDefinitionClass($class = null, array $arguments = array()) {
    $definition = new Definition($class, $arguments);
    $definition->setPublic(true);
    if (method_exists(Definition::class, 'setPrivate')) {
      $definition->setPrivate(FALSE);
    }
    return $definition;
  }


}
