<?php
/**
 * Copyright (C) 2021  Jaap Jansma (jaap.jansma@civicoop.org)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

namespace Civi\PhoneInputMask;

interface TypeInterface {

  /**
   * Returns true when the phone number is valid.
   * Returns an error message when the phone number is invalid.
   *
   * @param $phone
   *
   * @return true|false
   */
  public function validatePhone($phone);

  /**
   * Return a description of the type.
   *
   * E.g. 'Use the format +31 (0) 6123 456 78
   *
   * @return String[]
   */
  public function getExamples();

  /**
   * @return String
   */
  public function getTypeTitle();

  /**
   * Initialize the type
   *
   * @param String $name
   * @param String $title
   * @param array $configuration
   */
  public function initialize($name, $title, $configuration);

  /**
   * Returns true when this type has additional configuration.
   *
   * @return bool
   */
  public function hasConfiguration();

  /**
   * When this type has additional configuration you can add
   * the fields on the form with this function.
   *
   * @param \CRM_Core_Form $form
   * @param array $phoneInputMask
   */
  public function buildConfigurationForm(\CRM_Core_Form $form, $phoneInputMask=array());

  /**
   * When this type has configuration specify the template file name
   * for the configuration form.
   *
   * @return false|string
   */
  public function getConfigurationTemplateFileName();


  /**
   * Process the submitted values and create a configuration array
   *
   * @param $submittedValues
   * @return array
   */
  public function processConfiguration($submittedValues);

}
