<?php

require_once 'phoneinputmask.civix.php';
// phpcs:disable
use CRM_Phoneinputmask_ExtensionUtil as E;
// phpcs:enable

use \Symfony\Component\DependencyInjection\ContainerBuilder;

/**
 * Implements hook_civicrm_container()
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_container/
 */
function phoneinputmask_civicrm_container(ContainerBuilder $container) {
  $container->addCompilerPass(new Civi\PhoneInputMask\CompilerPass());
}

/**
 * @return \Civi\PhoneInputMask\Factory
 */
function phoneinputmask_get_factory() {
  $container = \Civi::container();
  if ($container->has('phone_input_mask_factory')) {
    return \Civi::service('phone_input_mask_factory');
  }
  return null;
}

/**
 * Implements hook_civicrm_validateForm().
 *
 * @param string $formName
 * @param array $fields
 * @param array $files
 * @param CRM_Core_Form $form
 * @param array $errors
 */
function phoneinputmask_civicrm_validateForm($formName, &$fields, &$files, &$form, &$errors) {
  CRM_Phoneinputmask_Utils_CommonForm::hookValidateForm($formName, $fields, $files, $form, $errors);
}

/**
 * Implements hook_civicrm_navigationMenu().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_navigationMenu
 */
function phoneinputmask_civicrm_navigationMenu(&$menu) {
  _phoneinputmask_civix_insert_navigation_menu($menu, 'Administer/Customize Data and Screens', array(
    'label' => E::ts('Phone Input Masks'),
    'name' => 'phone_input_masks',
    'url' => 'civicrm/admin/phoneinputmask?action=browse&reset=1',
    'permission' => 'administer CiviCRM',
    'operator' => 'OR',
    'separator' => 0,
  ));
  _phoneinputmask_civix_navigationMenu($menu);
}

/**
 * Implements hook_civicrm_config().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_config/
 */
function phoneinputmask_civicrm_config(&$config) {
  _phoneinputmask_civix_civicrm_config($config);
}

/**
 * Implements hook_civicrm_xmlMenu().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_xmlMenu
 */
function phoneinputmask_civicrm_xmlMenu(&$files) {
  _phoneinputmask_civix_civicrm_xmlMenu($files);
}

/**
 * Implements hook_civicrm_install().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_install
 */
function phoneinputmask_civicrm_install() {
  _phoneinputmask_civix_civicrm_install();
}

/**
 * Implements hook_civicrm_postInstall().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_postInstall
 */
function phoneinputmask_civicrm_postInstall() {
  _phoneinputmask_civix_civicrm_postInstall();
}

/**
 * Implements hook_civicrm_uninstall().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_uninstall
 */
function phoneinputmask_civicrm_uninstall() {
  _phoneinputmask_civix_civicrm_uninstall();
}

/**
 * Implements hook_civicrm_enable().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_enable
 */
function phoneinputmask_civicrm_enable() {
  _phoneinputmask_civix_civicrm_enable();
}

/**
 * Implements hook_civicrm_disable().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_disable
 */
function phoneinputmask_civicrm_disable() {
  _phoneinputmask_civix_civicrm_disable();
}

/**
 * Implements hook_civicrm_upgrade().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_upgrade
 */
function phoneinputmask_civicrm_upgrade($op, CRM_Queue_Queue $queue = NULL) {
  return _phoneinputmask_civix_civicrm_upgrade($op, $queue);
}

/**
 * Implements hook_civicrm_managed().
 *
 * Generate a list of entities to create/deactivate/delete when this module
 * is installed, disabled, uninstalled.
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_managed
 */
function phoneinputmask_civicrm_managed(&$entities) {
  _phoneinputmask_civix_civicrm_managed($entities);
}

/**
 * Implements hook_civicrm_caseTypes().
 *
 * Generate a list of case-types.
 *
 * Note: This hook only runs in CiviCRM 4.4+.
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_caseTypes
 */
function phoneinputmask_civicrm_caseTypes(&$caseTypes) {
  _phoneinputmask_civix_civicrm_caseTypes($caseTypes);
}

/**
 * Implements hook_civicrm_angularModules().
 *
 * Generate a list of Angular modules.
 *
 * Note: This hook only runs in CiviCRM 4.5+. It may
 * use features only available in v4.6+.
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_angularModules
 */
function phoneinputmask_civicrm_angularModules(&$angularModules) {
  _phoneinputmask_civix_civicrm_angularModules($angularModules);
}

/**
 * Implements hook_civicrm_alterSettingsFolders().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_alterSettingsFolders
 */
function phoneinputmask_civicrm_alterSettingsFolders(&$metaDataFolders = NULL) {
  _phoneinputmask_civix_civicrm_alterSettingsFolders($metaDataFolders);
}

/**
 * Implements hook_civicrm_entityTypes().
 *
 * Declare entity types provided by this module.
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_entityTypes
 */
function phoneinputmask_civicrm_entityTypes(&$entityTypes) {
  _phoneinputmask_civix_civicrm_entityTypes($entityTypes);
}

/**
 * Implements hook_civicrm_themes().
 */
function phoneinputmask_civicrm_themes(&$themes) {
  _phoneinputmask_civix_civicrm_themes($themes);
}

// --- Functions below this ship commented out. Uncomment as required. ---

/**
 * Implements hook_civicrm_preProcess().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_preProcess
 */
//function phoneinputmask_civicrm_preProcess($formName, &$form) {
//
//}
