<?php

use Civi\Test\HeadlessInterface;
use Civi\Test\HookInterface;
use Civi\Test\TransactionalInterface;

/**
 * PhoneInputMask API Test Case
 * @group headless
 */
class api_v3_PhoneInputMaskTest extends \PHPUnit\Framework\TestCase implements HeadlessInterface, HookInterface, TransactionalInterface {
  use \Civi\Test\Api3TestTrait;

  /**
   * Set up for headless tests.
   *
   * Civi\Test has many helpers, like install(), uninstall(), sql(), and sqlFile().
   *
   * See: https://docs.civicrm.org/dev/en/latest/testing/phpunit/#civitest
   */
  public function setUpHeadless() {
    return \Civi\Test::headless()
      ->installMe(__DIR__)
      ->apply();
  }

  /**
   * The setup() method is executed before the test is executed (optional).
   */
  public function setUp() {
    $table = CRM_Core_DAO_AllCoreTables::getTableForEntityName('PhoneInputMask');
    $this->assertTrue($table && CRM_Core_DAO::checkTableExists($table), 'There was a problem with extension installation. Table for ' . 'PhoneInputMask' . ' not found.');
    parent::setUp();
  }

  /**
   * The tearDown() method is executed after the test was executed (optional)
   * This can be used for cleanup.
   */
  public function tearDown() {
    parent::tearDown();
  }

  /**
   * Simple example test case.
   *
   * Note how the function name begins with the word "test".
   */
  public function testCreateGetDelete() {
    $created = $this->callAPISuccess('PhoneInputMask', 'create', [
      'title' => 'Test Phone Mask',
      'type' => 'mask',
      'configuration' => ['mask' => '(9900)-00000099', 'example' => '(0012)-12345678'],
      'is_active' => 1,
    ]);
    $this->assertTrue(is_numeric($created['id']));

    $get = $this->callAPISuccess('PhoneInputMask', 'get', []);
    $this->assertEquals(1, $get['count']);
    $configuration = json_decode($get['values'][$created['id']]['configuration'], true);
    $this->assertEquals('(9900)-00000099', $configuration['mask']);
    $this->assertEquals('test_phone_mask', $get['values'][$created['id']]['name']);

    $this->callAPISuccess('PhoneInputMask', 'delete', [
      'id' => $created['id'],
    ]);
  }

}
